@@ -1,18 +1,14 @@
+import os
 import time
 import requests
-from . import settings, GQLException
+from . import GQLException
 
-URL = settings.dgraph_url
-ACCESS_TOKEN = settings.dgraph_access_token
+URL = os.environ["DGRAPH_URL"]
 
 
 def execute(query_str: str, should_print: bool = False) -> dict:
     start = time.time()
-    j = requests.post(
-        URL,
-        json={"query": query_str},
-        headers={"X-Dgraph-AccessToken": ACCESS_TOKEN},
-    ).json()
+    j = requests.post(URL, json={"query": query_str}).json()
     print(
         f'took: {(time.time() - start) * 1000}, took internal: {int(j["extensions"]["tracing"]["duration"]) / (10 ** 6)}'
     )
