@@ -7,6 +7,23 @@ from fastapi.encoders import jsonable_encoder
 from .gql import GQLException
 
 
+def d_rez(refresh: bool = False, use_stale: bool = False, returns: T.Type = None):
+    """The problem w this is it does not do types"""
+
+    def outer(f: T.Callable):
+        def inner(
+            *args, refresh: bool = refresh, use_stale: bool = use_stale, **kwargs
+        ) -> returns:
+            resolver = f(*args, **kwargs)
+            return args[0].resolve(
+                name=f.__name__, resolver=resolver, refresh=refresh, use_stale=use_stale
+            )
+
+        return inner
+
+    return outer
+
+
 class Cache(BaseModel):
     val: T.Union[Node, T.List[Node], None]
     resolver: Resolver
@@ -51,12 +68,11 @@ class CacheManager(BaseModel):
         return len(self.cache) == 0
 
 
-Model = T.TypeVar("Model")
+NodeModel = T.TypeVar("NodeModel", bound="Node")
 
 
-class Node(BaseModel, T.Generic[Model]):
+class Node(BaseModel):
     _cache: CacheManager = PrivateAttr(default_factory=CacheManager)
-    _typename: T.ClassVar[str]
 
     id: str
 
@@ -71,7 +87,7 @@ class Node(BaseModel, T.Generic[Model]):
         d = {}
         subs = Node.__subclasses__()
         for sub in subs:
-            typename = sub._typename
+            typename = sub.GQL.typename
             if typename in d:
                 raise GQLException(
                     f"Two Nodes share the typename {typename}: ({sub.__name__}, {d[typename].__name__})"
@@ -85,7 +101,7 @@ class Node(BaseModel, T.Generic[Model]):
         return r
 
     def get_root_resolver(self) -> T.Type[Resolver]:
-        return Resolver.resolvers_by_typename()[self._typename]
+        return Resolver.resolvers_by_typename()[self.GQL.typename]
 
     @staticmethod
     def should_use_new_resolver(
@@ -97,20 +113,16 @@ class Node(BaseModel, T.Generic[Model]):
             return False
         if strict:
             return True
-        if old_r.json(exclude={"children_resolvers"}) != new_r.json(
-            exclude={"children_resolvers"}
-        ):
+        if old_r.json(exclude={"edges"}) != new_r.json(exclude={"edges"}):
             print(
-                f'excluding children resolvers here..., {old_r.json(exclude={"children_resolvers"})=}, {new_r.json(exclude={"children_resolvers"})=}'
+                f'excluding children resolvers here..., {old_r.json(exclude={"edges"})=}, {new_r.json(exclude={"edges"})=}'
             )
             return True
         # now do the same for children
-        for child_resolver_name in new_r.children_resolvers.__fields__.keys():
-            new_child_resolver = getattr(new_r.children_resolvers, child_resolver_name)
+        for child_resolver_name in new_r.edges.__fields__.keys():
+            new_child_resolver = getattr(new_r.edges, child_resolver_name)
             if new_child_resolver:
-                old_child_resolver = getattr(
-                    old_r.children_resolvers, child_resolver_name
-                )
+                old_child_resolver = getattr(old_r.edges, child_resolver_name)
                 if not old_child_resolver:
                     return True
                 if Node.should_use_new_resolver(
@@ -128,7 +140,7 @@ class Node(BaseModel, T.Generic[Model]):
         refresh: bool = False,
         strict: bool = False,
         use_stale: bool = False,
-    ) -> T.Optional[T.Union[Model, T.List[Model]]]:
+    ) -> T.Optional[T.Union[NodeModel, T.List[NodeModel]]]:
         if refresh:
             self.cache.remove(name)
         # see if the resolvers do not match
@@ -143,10 +155,25 @@ class Node(BaseModel, T.Generic[Model]):
                 )
                 self.cache.remove(name)
         if not self.cache.exists(name):
-            obj = getattr(self.get_root_resolver()(), name)(resolver).get(id=self.id)
+            root_resolver = self.get_root_resolver()
+            get_params = self.GQL.GetParams(id=self.id)
+            edge_params = self.GQL.Edges.parse_obj({name: resolver})
+            obj = root_resolver(edges=edge_params).get(get_params)
             self.cache.replace(key=name, cache=obj.cache.get(name))
         return self.cache.get_val(name)
 
+    class GQL:
+        typename: T.ClassVar[str]
+
+        class GetParams(BaseModel):
+            id: T.Optional[str] = None  # TODO this should be no None right?
+
+        class QueryParams(BaseModel):
+            pass
+
+        class Edges(BaseModel):
+            pass
+
 
 from .resolver import Resolver
 
