@@ -102,7 +102,7 @@ class Resolver(
                 for field_name, val in kwargs.items()
             ]
         )
-        query_name = f"get{self.model.__name__}"
+        query_name = f"get{self.model.GQL.typename}"
         s = f"{{ {query_name}({inner_params}){self.gql_fields_str()} }}"
         print(s)
         obj = execute(query_str=s)["data"][query_name]
@@ -111,7 +111,7 @@ class Resolver(
         return None
 
     def query(self) -> T.List[NodeType]:
-        query_name = f"query{self.model.__name__}"
+        query_name = f"query{self.model.GQL.typename}"
         s = f"{{ {query_name}{self.params_and_fields()} }}"
         print(s)
         lst: T.List[dict] = execute(query_str=s)["data"][query_name]
